# The Shdw Package
The Shdw Package was originally made for any useful/not useful functions. There may be a random function you need, just look to the Shdw package!
## Packages used:
+ replit
+ pygame
+ pyfiglet
## Other info
If you are going to import the package, I would suggest importing it at the very start of your program before you do anything. This is becuase
A. I am importing pygame, and initializing it
B. I am `pip install`ing pyfiglet
(I already have it clearing up the console for you)
## Pygame Usage
Use `init_pygame(width, height, title)` to create and return your window. Variables are below.
+ GUI -> pygame
+ GUI_events -> pygame.event
+ GUI_out -> pygame.draw
+ GUI_clock -> pygame.time
## Replit Usage
